### 0.10.5 {small}`2024-06-11`

```{rubric} Bug fixes
```
* fixes an issue with `tl.umap` and `init_pos` {pr}`197` {smaller}`S Dicks`
* fixes an issue with `pp.highly_variable_genes` for `flavor = 'seurat_v3'` with sparse `csc` {pr}`199` {smaller}`S Dicks`
* adds `AnyRandom` to `_utils` {pr}`200` {smaller}`S Dicks`

```{rubric} Misc
```
* updates installer for `rapids-24.06` {pr}`205` {smaller}`S Dicks`
